@@ -1,4 +1,4 @@
-//@line 4 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/nsUrlClassifierLib.js"
+//@line 4 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/nsUrlClassifierLib.js"
 
 // We wastefully reload the same JS files across components.  This puts all
 // the common JS files used by safebrowsing and url-classifier into a
@@ -10,7 +10,7 @@ const G_GDEBUG = false;
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
-//@line 4 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/content/moz/lang.js"
+//@line 4 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/content/moz/lang.js"
 
 
 /**
@@ -90,7 +90,7 @@ Function.prototype.inherits = function(parentCtor) {
   this.superClass_ = parentCtor.prototype;
   this.prototype = new tempCtor();
 }
-//@line 4 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/content/moz/preferences.js"
+//@line 4 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/content/moz/preferences.js"
 
 
 // Class for manipulating preferences. Aside from wrapping the pref
@@ -273,7 +273,7 @@ G_Preferences.prototype.removeObserver = function(which, callback) {
  */
 G_Preferences.prototype.removeAllObservers = function() {
   for (var which in this.observers_) {
-    for each (var observer in this.observers_[which].observers) {
+    for (var observer of this.observers_[which].observers) {
       this.prefs_.removeObserver(which, observer);
     }
   }
@@ -321,9 +321,9 @@ G_PreferenceObserver.prototype.QueryInterface = function(iid) {
   throw Components.results.NS_ERROR_NO_INTERFACE;
 }
 
-//@line 4 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/content/moz/debug.js"
+//@line 4 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/content/moz/debug.js"
 
-//@line 834 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/content/moz/debug.js"
+//@line 834 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/content/moz/debug.js"
 
 // Stubs for the debugging aids scattered through this component.
 // They will be expanded if you compile yourself a debug build.
@@ -357,7 +357,7 @@ this.G_debugService = {
     reportScriptError_: () => {}
 };
 
-//@line 4 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/content/moz/alarm.js"
+//@line 4 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/content/moz/alarm.js"
 
 
 // An Alarm fires a callback after a certain amount of time, or at
@@ -512,7 +512,7 @@ G_ConditionalAlarm.prototype.notify = function(timer) {
     this.cancel();
   }
 }
-//@line 4 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/content/moz/cryptohasher.js"
+//@line 4 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/content/moz/cryptohasher.js"
 
 
 // A very thin wrapper around nsICryptoHash. It's not strictly
@@ -655,7 +655,7 @@ G_CryptoHasher.prototype.toHex_ = function(str) {
   return hexrep.join('');
 }
 
-//@line 4 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/content/moz/observer.js"
+//@line 4 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/content/moz/observer.js"
 
 
 // A couple of classes to simplify creating observers. 
@@ -756,7 +756,7 @@ G_ObserverServiceObserver.prototype.observe_ = function(subject, topic, data) {
     this.unregister();
 }
 
-//@line 4 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/content/moz/protocol4.js"
+//@line 4 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/content/moz/protocol4.js"
 
 
 // A helper class that knows how to parse from and serialize to
@@ -832,8 +832,9 @@ G_Protocol4Parser.prototype.serialize = function(map) {
   return text;
 }
 
-//@line 22 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/nsUrlClassifierLib.js"
+//@line 22 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/nsUrlClassifierLib.js"
 
+//@line 1 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/content/request-backoff.js"
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -950,7 +951,7 @@ RequestBackoff.prototype.isErrorStatus = function(status) {
           HTTP_TEMPORARY_REDIRECT == status);
 }
 
-//@line 4 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/content/xml-fetcher.js"
+//@line 4 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/content/xml-fetcher.js"
 
 // A simple class that encapsulates a request. You'll notice the
 // style here is different from the rest of the extension; that's
@@ -992,7 +993,7 @@ this.PROT_XMLFetcher = function PROT_XMLFetcher() {
   this._request = PROT_NewXMLHttpRequest();
   // implements nsILoadContext
   this.appId = Ci.nsIScriptSecurityManager.SAFEBROWSING_APP_ID;
-  this.isInBrowserElement = false;
+  this.isInIsolatedMozBrowserElement = false;
   this.usePrivateBrowsing = false;
   this.isContent = false;
 }
@@ -1002,11 +1003,11 @@ PROT_XMLFetcher.prototype = {
    * Function that will be called back upon fetch completion.
    */
   _callback: null,
-  
+
 
   /**
    * Fetches some content.
-   * 
+   *
    * @param page URL to fetch
    * @param callback Function to call back when complete.
    */
@@ -1015,6 +1016,10 @@ PROT_XMLFetcher.prototype = {
     this._request = PROT_NewXMLHttpRequest();
     this._callback = callback;
     var asynchronous = true;
+    this._request.loadInfo.originAttributes = {
+      appId: this.appId,
+      inIsolatedMozBrowser: this.isInIsolatedMozBrowserElement
+    };
     this._request.open("GET", page, asynchronous);
     this._request.channel.notificationCallbacks = this;
 
@@ -1048,7 +1053,7 @@ PROT_XMLFetcher.prototype = {
     var responseText = null;
     var status = Components.results.NS_ERROR_NOT_AVAILABLE;
     try {
-      G_Debug(this, "xml fetch status code: \"" + 
+      G_Debug(this, "xml fetch status code: \"" +
               fetcher._request.status + "\"");
       status = fetcher._request.status;
       responseText = fetcher._request.responseText;
@@ -1070,7 +1075,7 @@ PROT_XMLFetcher.prototype = {
                                          Ci.nsISupports,
                                          Ci.nsILoadContext])
 };
-//@line 25 "/build/bluegriffon/src/mozilla-central-fec90cbfbaad/toolkit/components/url-classifier/nsUrlClassifierLib.js"
+//@line 25 "/build/bluegriffon/src/mozilla-central-f14898695ee0/toolkit/components/url-classifier/nsUrlClassifierLib.js"
 
 // Expose this whole component.
 var lib = this;
